@@ -1,4 +1,5 @@
-setMethod("asJSON", "list", function(x, collapse = TRUE, na = NULL, oldna = NULL, ...) {
+setMethod("asJSON", "list", function(x, collapse = TRUE, na = NULL, oldna = NULL,
+  is_df = FALSE, auto_unbox = FALSE, ...) {
 
   # reset na arg when called from data frame
   if(identical(na, "NA")){
@@ -26,7 +27,11 @@ setMethod("asJSON", "list", function(x, collapse = TRUE, na = NULL, oldna = NULL
   # }
 
   # note we are NOT passing on the container argument.
-  tmp <- vapply(x, asJSON, character(1), na = na, ...)
+  tmp <- if(is_df && auto_unbox){
+    vapply(x, function(y, ...){asJSON(y, auto_unbox = is.list(y), ...)}, character(1), na = na, ...)
+  } else {
+    vapply(x, asJSON, character(1), na = na, auto_unbox = auto_unbox, ...)
+  }
 
   if (!is.null(names(x))) {
     if(!collapse){
