@@ -2,7 +2,8 @@
 toJSON <- function(x, dataframe = c("rows", "columns"), matrix = c("rowmajor", "columnmajor"),
   Date = c("ISO8601", "epoch"), POSIXt = c("string", "ISO8601", "epoch", "mongo"),
   factor = c("string", "integer"), complex = c("string", "list"), raw = c("base64", "hex", "mongo"),
-  na=c("null", "string"), auto_unbox = FALSE, digits = 4, pretty = FALSE, force = FALSE, ...) {
+  null = c("list", "null"), na = c("null", "string"), auto_unbox = FALSE, digits = 4,
+  pretty = FALSE, force = FALSE, ...) {
 
   # validate args
   dataframe <- match.arg(dataframe)
@@ -12,6 +13,15 @@ toJSON <- function(x, dataframe = c("rows", "columns"), matrix = c("rowmajor", "
   factor <- match.arg(factor)
   complex <- match.arg(complex)
   raw <- match.arg(raw)
+  null <- match.arg(null)
+
+  # force
+  x <- force(x)
+
+  # edge case because 'null' in itself is not valid json
+  if(is.null(x)){
+    null <- "list"
+  }
 
   #this is just to check, we keep method-specific defaults
   if(!missing(na)){
@@ -20,13 +30,10 @@ toJSON <- function(x, dataframe = c("rows", "columns"), matrix = c("rowmajor", "
     na <- NULL
   }
 
-  # force
-  x <- force(x)
-
   # dispatch
   ans <- asJSON(x, dataframe = dataframe, Date = Date, POSIXt = POSIXt, factor = factor,
     complex = complex, raw = raw, matrix = matrix, auto_unbox = auto_unbox, digits = digits,
-    na = na, force = force, ...)
+    na = na, null = null, force = force, ...)
 
   #prettify
   if (isTRUE(pretty)) {
